pub struct MkFile { /* private fields */ }Expand description
Builder for configuring a file to copy into a container.
Implementations
Sourceimpl MkFile
impl MkFile
Sourcepub fn path(path: &str) -> MkFile
pub fn path(path: &str) -> MkFile
Defines a file to add to the container.
This should be passed to Container::file.
The path is the path inside the container to create the file.
pub fn contents(self, contents: impl Into<Vec<u8>>) -> Self
pub fn mode(self, mode: u32) -> Self
pub fn uid(self, uid: u64) -> Self
pub fn gid(self, gid: u64) -> Self