Function cargo_test_support::project_in
source · pub fn project_in(dir: &str) -> ProjectBuilderExpand description
Generates a project layout in given directory, see ProjectBuilder
pub fn project_in(dir: &str) -> ProjectBuilderGenerates a project layout in given directory, see ProjectBuilder