Function cargo_test_support::threaded_timeout
source · pub fn threaded_timeout<F, R>(n: u32, f: F) -> RExpand description
Helper that runs some function, and waits up to n tenths of a second for
it to finish.
pub fn threaded_timeout<F, R>(n: u32, f: F) -> RHelper that runs some function, and waits up to n tenths of a second for
it to finish.