Function cargo_test_support::git::add
source · pub fn add(repo: &Repository)Expand description
(git2) Add all files in the working directory to the git index
pub fn add(repo: &Repository)(git2) Add all files in the working directory to the git index