Function cargo_test_support::paths::global_root
source · pub fn global_root() -> PathBufExpand description
Path to the parent directory of all test roots
ex: $CARGO_TARGET_TMPDIR/cit
pub fn global_root() -> PathBufPath to the parent directory of all test roots
ex: $CARGO_TARGET_TMPDIR/cit