Command

Struct Command 

pub struct Command { /* private fields */ }
Process spawning for testing of non-interactive commands

Implementations

Source

impl Command

Builder API

pub fn new(program: impl AsRef<OsStr>) -> Command

pub fn from_std(cmd: Command) -> Command

Constructs a new Command from a std Command.

pub fn with_assert(self, config: Assert) -> Command

Customize the assertion behavior

pub fn arg(self, arg: impl AsRef<OsStr>) -> Command

Adds an argument to pass to the program.

Only one argument can be passed per use. So instead of:

.arg("-C /path/to/repo")

usage would be:

.arg("-C")
.arg("/path/to/repo")

To pass multiple arguments see args.

Examples

Basic usage:

use snapbox::cmd::Command;

Command::new("ls")
        .arg("-l")
        .arg("-a")
        .assert()
        .success();
pub fn args(self, args: impl IntoIterator<Item = impl AsRef<OsStr>>) -> Command

Adds multiple arguments to pass to the program.

To pass a single argument see arg.

Examples

Basic usage:

use snapbox::cmd::Command;

Command::new("ls")
        .args(&["-l", "-a"])
        .assert()
        .success();
pub fn env(self, key: impl AsRef<OsStr>, value: impl AsRef<OsStr>) -> Command

Inserts or updates an environment variable mapping.

Note that environment variable names are case-insensitive (but case-preserving) on Windows, and case-sensitive on all other platforms.

Examples

Basic usage:

use snapbox::cmd::Command;

Command::new("ls")
        .env("PATH", "/bin")
        .assert()
        .failure();
pub fn envs( self, vars: impl IntoIterator<Item = (impl AsRef<OsStr>, impl AsRef<OsStr>)>, ) -> Command

Adds or updates multiple environment variable mappings.

Examples

Basic usage:

use snapbox::cmd::Command;
use std::process::Stdio;
use std::env;
use std::collections::HashMap;

let filtered_env : HashMap<String, String> =
    env::vars().filter(|&(ref k, _)|
        k == "TERM" || k == "TZ" || k == "LANG" || k == "PATH"
    ).collect();

Command::new("printenv")
        .env_clear()
        .envs(&filtered_env)
        .assert()
        .success();
pub fn env_remove(self, key: impl AsRef<OsStr>) -> Command

Removes an environment variable mapping.

Examples

Basic usage:

use snapbox::cmd::Command;

Command::new("ls")
        .env_remove("PATH")
        .assert()
        .failure();
pub fn env_clear(self) -> Command

Clears the entire environment map for the child process.

Examples

Basic usage:

use snapbox::cmd::Command;

Command::new("ls")
        .env_clear()
        .assert()
        .failure();
pub fn current_dir(self, dir: impl AsRef<Path>) -> Command

Sets the working directory for the child process.

Platform-specific behavior

If the program path is relative (e.g., "./script.sh"), it’s ambiguous whether it should be interpreted relative to the parent’s working directory or relative to current_dir. The behavior in this case is platform specific and unstable, and it’s recommended to use canonicalize to get an absolute program path instead.

Examples

Basic usage:

use snapbox::cmd::Command;

Command::new("ls")
        .current_dir("/bin")
        .assert()
        .success();
pub fn stdin(self, stream: impl IntoData) -> Command

Write buffer to stdin when the Command is run.

Examples
use snapbox::cmd::Command;

let mut cmd = Command::new("cat")
    .arg("-et")
    .stdin("42")
    .assert()
    .stdout_eq("42");
Source

impl Command

Run Command

pub fn assert(self) -> OutputAssert

Run the command and assert on the results

use snapbox::cmd::Command;

let mut cmd = Command::new("cat")
    .arg("-et")
    .stdin("42")
    .assert()
    .stdout_eq("42");
pub fn output(self) -> Result<Output, Error>